[mew-dist 26969] Re: 拡張子 .eml
Teruyuki Morimura
teruyuki_morimura at example.com
2006年 5月 11日 (木) 01:29:16 JST
森村です。
At Wed, 10 May 2006 08:27:08 +0900 (JST),
Kazu Yamamoto (山本和彦) <kazu at example.com> wrote:
>あああ、mew-suffix は、.emacs で設定して下さい。.mew では反映されません。
>
>他の変数もそうですが、.emacs で設定する必要があるというこの制約は、近日
>中に直します。(昔、アイディアを思いついていたのに、実装していなかっ
>た。。。)
[mew-dist 26968] .emacs
のメールの後、試してみました。問題ないようです。
これで、かなり幸せになれました。
gdsgrep.rb は、次のように変更するといけました。
--- gdsgrep.rb.orig 2006-05-10 11:23:43.386272000 -0500
+++ gdsgrep.rb 2006-05-10 11:26:00.733768000 -0500
@@ -187,16 +187,6 @@
# XXX: encode query string
- # basedir is "x:hogehoge", delete drive letter.
- if basedir
- if basedir.size > 3 && basedir[1] == ?:
- # append basedir parts to querystr.
- querystr = basedir[3..-1] + '+' + querystr
- end
- # convert path separator('\') to query separator('+').
- querystr = querystr.tr('\\', '+')
- end
-
# construct final query string.
querystr = querystr + '&format=xml&num=' + querynum.to_s
@@ -210,23 +200,25 @@
# search document and print.
@doc.elements.each("results/result") { |e|
@category = e.elements['category'].text
- @text = e.elements['url'].text
- # when category is "file" and target file exists,
+ # when category is "email" and target file exists,
# show filename.
- if @category == "file" && File.exists?(@text)
- if basedir
- # compare with basedir.
- if @text[0..basedir.size-1] == basedir[0..-1]
- if $OPT_s
- printf "#{@text.tr('\\', '/')}\n"
- else
- printf "#{@text}\n"
+ if @category == "email"
+ @text = e.elements['folder'].text
+ if File.exists?(@text)
+ if basedir
+ # compare with basedir.
+ if @text[0..basedir.size-1].downcase == basedir[0..-1].downcase
+ if $OPT_s
+ printf "#{@text.tr('\\', '/')}\n"
+ else
+ printf "#{@text}\n"
+ end
end
- end
- else
- # when basedir is not specified, show all.
- printf "#{@text}\n"
+ else
+ # when basedir is not specified, show all.
+ printf "#{@text}\n"
+ end
end
end
}
Mew-dist メーリングリストの案内